@@ -266,7 +266,7 @@ Do the computation
 Hand-checkable example given in [Myers1980] p 61 - see JSS paper
 
 >>> tm = numpy.reshape( [1, 3, 4, 4, 5, 2, 2, 3, 3, 4, 3, 1, 1, 1, 3, 4, 2,
-...                      3, 3, 2, 5, 3, 4, 4, 1], (5,5), "F" )
+...                      3, 3, 2, 5, 3, 4, 4, 1], (5,5) )
 
 """
     # ENDIMPORT
